@@ -22,7 +22,7 @@ from delicious_cake.options import DetailResourceOptions, ListResourceOptions
 from delicious_cake.exceptions import (
     ImmediateHttpResponse, BadRequest,
     UnsupportedSerializationFormat, UnsupportedDeserializationFormat,
-    WrongNumberOfValues, ResourceEntityError, FormValidationError,)
+    WrongNumberOfValues, ResourceEntityError, ValidationError,)
 
 __all__ = ('ResourceResponse', 'Resource',
            'DetailResource', 'ListResource', 'UploadResource',)
@@ -72,7 +72,12 @@ class Resource(View):
             self.args = args
             self.kwargs = kwargs
 
-            response = handler(request, *args, **kwargs)
+            try:
+                response = handler(request, *args, **kwargs)
+            except ValidationError, e:
+                # Catch ValidationError here for non-resources can throw them.
+                self.raise_validation_error(request, e.form_errors)
+
         except ImmediateHttpResponse, e:
             if e.response is not None:
                 response = e.response
@@ -208,8 +213,6 @@ class Resource(View):
 
         if isinstance(exception, NOT_FOUND_EXCEPTIONS):
             response = cake_http.HttpNotFound(content_type=content_type)
-        elif isinstance(exception, FormValidationError):
-            self.raise_validation_error(request, exception.form_errors)
         elif isinstance(exception, UnsupportedSerializationFormat):
             response = cake_http.HttpNotAcceptable(content_type=content_type)
         elif isinstance(exception, UnsupportedDeserializationFormat):
